Author: bugman
Date: Thu Feb 5 19:14:41 2015
New Revision: 27568
URL: http://svn.gna.org/viewcvs/relax?rev=27568&view=rev
Log:
Fix for the N_state_model.test_statistics system test.
The deselected spins and interatomic data containers are now taken into account
for the RDC and PCS
data point counts.
Modified:
trunk/test_suite/system_tests/n_state_model.py
Modified: trunk/test_suite/system_tests/n_state_model.py
URL:
http://svn.gna.org/viewcvs/relax/trunk/test_suite/system_tests/n_state_model.py?rev=27568&r1=27567&r2=27568&view=diff
==============================================================================
--- trunk/test_suite/system_tests/n_state_model.py (original)
+++ trunk/test_suite/system_tests/n_state_model.py Thu Feb 5 19:14:41 2015
@@ -1057,8 +1057,8 @@
# The number of parameters (4 alignment tensors and 3 probabilities).
k = 5*4 + 3
- # The number of data sets (4 sets of 10 RDCs and 22 PCSs).
- n = 10*4 + 22*4
+ # The number of data sets (4 sets of 9 RDCs and 20 PCSs).
+ n = 9*4 + 20*4
# Loop over the solution and non-solution.
for i in range(2):
_______________________________________________
relax (http://www.nmr-relax.com)
This is the relax-commits mailing list
[email protected]
To unsubscribe from this list, get a password
reminder, or change your subscription options,
visit the list information page at
https://mail.gna.org/listinfo/relax-commits